Security Advisories (1)
CVE-2015-8978 (2015-07-21)

An example attack consists of defining 10 or more XML entities, each defined as consisting of 10 of the previous entity, with the document consisting of a single instance of the largest entity, which expands to one billion copies of the first entity. The amount of computer memory used for handling an external SOAP call would likely exceed that available to the process parsing the XML.

NAME

SOAP::Transport::POP3 - Server side POP3 support for SOAP::Lite

SYNOPSIS

use SOAP::Transport::POP3;

my $server = SOAP::Transport::POP3::Server
  -> new('pop://pop.mail.server')
  # if you want to have all in one place
  # -> new('pop://user:password@pop.mail.server') 
  # or, if you have server that supports MD5 protected passwords
  # -> new('pop://user:password;AUTH=+APOP@pop.mail.server') 
  # specify list of objects-by-reference here 
  -> objects_by_reference(qw(My::PersistentIterator My::SessionIterator My::Chat))
  # specify path to My/Examples.pm here
  -> dispatch_to('/Your/Path/To/Deployed/Modules', 'Module::Name', 'Module::method') 
;
# you don't need to use next line if you specified your password in new()
$server->login('user' => 'password') or die "Can't authenticate to POP3 server\n";

# handle will return number of processed mails
# you can organize loop if you want
do { $server->handle } while sleep 10;

# you may also call $server->quit explicitly to purge deleted messages

DESCRIPTION

COPYRIGHT

Copyright (C) 2000-2001 Paul Kulchenko. All rights reserved.

This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

AUTHOR

Paul Kulchenko (paulclinger@yahoo.com)